@@ -13,9 +13,14 @@ Usage (module):
     import jc.parsers.file
     result = jc.parsers.file.parse(file_command_output)
 
-Compatibility:
+Schema:
 
-    'linux', 'aix', 'freebsd', 'darwin'
+    [
+      {
+        "filename":   string,
+        "type   ":    string
+      }
+    ]
 
 Examples:
 
@@ -57,7 +62,8 @@ import jc.parsers.universal
 
 
 class info():
-    version = '1.2'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.3'
     description = '`file` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -70,7 +76,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -80,14 +86,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "filename":   string,
-            "type   ":    string
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
     # No further processing
     return proc_data
@@ -137,4 +136,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
