@@ -9,9 +9,16 @@ Usage (module):
     import jc.parsers.hosts
     result = jc.parsers.hosts.parse(hosts_file_output)
 
-Compatibility:
+Schema:
 
-    'linux', 'darwin', 'cygwin', 'win32', 'aix', 'freebsd'
+    [
+      {
+        "ip":           string,
+        "hostname": [
+                        string
+        ]
+      }
+    ]
 
 Examples:
 
@@ -66,7 +73,8 @@ import jc.utils
 
 
 class info():
-    version = '1.2'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.3'
     description = '`/etc/hosts` file parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -78,7 +86,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -88,16 +96,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "ip":           string,
-            "hostname": [
-                            string
-            ]
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
 
     # no additional processing needed
@@ -157,4 +156,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
