@@ -35,14 +35,26 @@ Schema:
       "round_trip_ms_stddev":        float,
       "responses": [
         {
-          "type":                    string,        # ('reply' or 'timeout')
+          "type":                    string,        # 'reply', 'timeout', 'unparsable_line', etc. See `_error_type.type_map` for all options
+          "unparsed_line":           string,        # only if an 'unparsable_line' type
           "timestamp":               float,
           "bytes":                   integer,
           "response_ip":             string,
           "icmp_seq":                integer,
           "ttl":                     integer,
           "time_ms":                 float,
-          "duplicate":               boolean
+          "duplicate":               boolean,
+          "vr":                      integer,       # hex value converted to decimal
+          "hl":                      integer,       # hex value converted to decimal
+          "tos":                     integer,       # hex value converted to decimal
+          "len":                     integer,       # hex value converted to decimal
+          "id":                      integer,       # hex value converted to decimal
+          "flg":                     integer,       # hex value converted to decimal
+          "off":                     integer,       # hex value converted to decimal
+          "pro":                     integer,       # hex value converted to decimal
+          "cks":                     ingeger,       # hex value converted to decimal
+          "src":                     string,
+          "dst":                     string
         }
       ]
     }
@@ -94,7 +106,6 @@ Examples:
       ]
     }
 
-
     $ ping -c 3 -p ff cnn.com | jc --ping -p -r
     {
       "destination_ip": "151.101.129.67",
@@ -141,12 +152,13 @@ Examples:
     }
 """
 import string
+import ipaddress
 import jc.utils
 
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.4'
+    version = '1.5'
     description = '`ping` and `ping6` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -171,7 +183,8 @@ def _process(proc_data):
 
         Dictionary. Structured data to conform to the schema.
     """
-    int_list = ['data_bytes', 'packets_transmitted', 'packets_received', 'bytes', 'icmp_seq', 'ttl', 'duplicates']
+    int_list = ['data_bytes', 'packets_transmitted', 'packets_received', 'bytes', 'icmp_seq', 'ttl',
+                'duplicates', 'vr', 'hl', 'tos', 'len', 'id', 'flg', 'off', 'pro', 'cks']
     float_list = ['packet_loss_percent', 'round_trip_ms_min', 'round_trip_ms_avg', 'round_trip_ms_max',
                   'round_trip_ms_stddev', 'timestamp', 'time_ms']
 
@@ -193,6 +206,54 @@ def _process(proc_data):
     return proc_data
 
 
+def _ipv6_in(line):
+    line_list = line.replace('(', ' ').replace(')', ' ').replace(',', ' ').replace('%', ' ').split()
+    ipv6 = False
+    for item in line_list:
+        try:
+            _ = ipaddress.IPv6Address(item)
+            ipv6 = True
+        except Exception:
+            pass
+    return ipv6
+
+
+def _error_type(line):
+    # from https://github.com/dgibson/iputils/blob/master/ping.c
+    # https://android.googlesource.com/platform/external/ping/+/8fc3c91cf9e7f87bc20b9e6d3ea2982d87b70d9a/ping.c
+    # https://opensource.apple.com/source/network_cmds/network_cmds-328/ping.tproj/ping.c
+    type_map = {
+        'Destination Net Unreachable': 'destination_net_unreachable',
+        'Destination Host Unreachable': 'destination_host_unreachable',
+        'Destination Protocol Unreachable': 'destination_protocol_unreachable',
+        'Destination Port Unreachable': 'destination_port_unreachable',
+        'Frag needed and DF set': 'frag_needed_and_df_set',
+        'Source Route Failed': 'source_route_failed',
+        'Destination Net Unknown': 'destination_net_unknown',
+        'Destination Host Unknown': 'destination_host_unknown',
+        'Source Host Isolated': 'source_host_isolated',
+        'Destination Net Prohibited': 'destination_net_prohibited',
+        'Destination Host Prohibited': 'destination_host_prohibited',
+        'Destination Net Unreachable for Type of Service': 'destination_net_unreachable_for_type_of_service',
+        'Destination Host Unreachable for Type of Service': 'destination_host_unreachable_for_type_of_service',
+        'Packet filtered': 'packet_filtered',
+        'Precedence Violation': 'precedence_violation',
+        'Precedence Cutoff': 'precedence_cutoff',
+        'Dest Unreachable, Bad Code': 'dest_unreachable_bad_code',
+        'Redirect Network': 'redirect_network',
+        'Redirect Host': 'redirect_host',
+        'Redirect Type of Service and Network': 'redirect_type_of_service_and_network',
+        'Redirect, Bad Code': 'redirect_bad_code',
+        'Time to live exceeded': 'time_to_live_exceeded',
+        'Frag reassembly time exceeded': 'frag_reassembly_time_exceeded',
+        'Time exceeded, Bad Code': 'time_exceeded_bad_code'
+    }
+
+    for err_type, code in type_map.items():
+        if err_type in line:
+            return code
+
+
 def _linux_parse(data):
     raw_output = {}
     ping_responses = []
@@ -303,36 +364,41 @@ def _linux_parse(data):
                 continue
 
             # normal responses
-            else:
+            elif ' bytes from ' in line:
+                try:
+                    line = line.replace('(', ' ').replace(')', ' ').replace('=', ' ')
 
-                line = line.replace('(', ' ').replace(')', ' ').replace('=', ' ')
+                    # positions of items depend on whether ipv4/ipv6 and/or ip/hostname is used
+                    if ipv4 and not hostname:
+                        bts, rip, iseq, t2l, tms = (0, 3, 5, 7, 9)
+                    elif ipv4 and hostname:
+                        bts, rip, iseq, t2l, tms = (0, 4, 7, 9, 11)
+                    elif not ipv4 and not hostname:
+                        bts, rip, iseq, t2l, tms = (0, 3, 5, 7, 9)
+                    elif not ipv4 and hostname:
+                        bts, rip, iseq, t2l, tms = (0, 4, 7, 9, 11)
 
-                # positions of items depend on whether ipv4/ipv6 and/or ip/hostname is used
-                if ipv4 and not hostname:
-                    bts, rip, iseq, t2l, tms = (0, 3, 5, 7, 9)
-                elif ipv4 and hostname:
-                    bts, rip, iseq, t2l, tms = (0, 4, 7, 9, 11)
-                elif not ipv4 and not hostname:
-                    bts, rip, iseq, t2l, tms = (0, 3, 5, 7, 9)
-                elif not ipv4 and hostname:
-                    bts, rip, iseq, t2l, tms = (0, 4, 7, 9, 11)
+                    # if timestamp option is specified, then shift everything right by one
+                    timestamp = False
+                    if line[0] == '[':
+                        timestamp = True
+                        bts, rip, iseq, t2l, tms = (bts + 1, rip + 1, iseq + 1, t2l + 1, tms + 1)
 
-                # if timestamp option is specified, then shift everything right by one
-                timestamp = False
-                if line[0] == '[':
-                    timestamp = True
-                    bts, rip, iseq, t2l, tms = (bts + 1, rip + 1, iseq + 1, t2l + 1, tms + 1)
-
-                response = {
-                    'type': 'reply',
-                    'timestamp': line.split()[0].lstrip('[').rstrip(']') if timestamp else None,
-                    'bytes': line.split()[bts],
-                    'response_ip': line.split()[rip].rstrip(':'),
-                    'icmp_seq': line.split()[iseq],
-                    'ttl': line.split()[t2l],
-                    'time_ms': line.split()[tms],
-                    'duplicate': True if 'DUP!' in line else False
-                }
+                    response = {
+                        'type': 'reply',
+                        'timestamp': line.split()[0].lstrip('[').rstrip(']') if timestamp else None,
+                        'bytes': line.split()[bts],
+                        'response_ip': line.split()[rip].rstrip(':'),
+                        'icmp_seq': line.split()[iseq],
+                        'ttl': line.split()[t2l],
+                        'time_ms': line.split()[tms],
+                        'duplicate': True if 'DUP!' in line else False
+                    }
+                except Exception:
+                    response = {
+                        'type': 'unparsable_line',
+                        'unparsed_line': line
+                    }
 
                 ping_responses.append(response)
                 continue
@@ -347,6 +413,7 @@ def _bsd_parse(data):
     ping_responses = []
     pattern = None
     footer = False
+    ping_error = False
 
     linedata = data.splitlines()
 
@@ -420,7 +487,7 @@ def _bsd_parse(data):
         # ping response lines
         else:
             # ipv4 lines
-            if ',' not in line:
+            if not _ipv6_in(line):
 
                 # request timeout
                 if line.startswith('Request timeout for '):
@@ -431,9 +498,80 @@ def _bsd_parse(data):
                     ping_responses.append(response)
                     continue
 
+                # catch error responses
+                err = _error_type(line)
+                if err:
+                    response = {
+                        'type': err
+                    }
+
+                    try:
+                        response['bytes'] = line.split()[0]
+                        response['response_ip'] = line.split()[4].strip(':').strip('(').strip(')')
+                    except Exception:
+                        pass
+
+                    ping_error = True
+                    continue
+
+                if ping_error:
+                    if line.startswith('Vr'):
+                        continue
+                    else:
+                        error_line = line.split()
+
+                        try:
+                            response.update(
+                                {
+                                    'vr': int(error_line[0], 16),   # convert from hex to decimal
+                                    'hl': int(error_line[1], 16),
+                                    'tos': int(error_line[2], 16),
+                                    'len': int(error_line[3], 16),
+                                    'id': int(error_line[4], 16),
+                                    'flg': int(error_line[5], 16),
+                                    'off': int(error_line[6], 16),
+                                    'ttl': int(error_line[7], 16),
+                                    'pro': int(error_line[8], 16),
+                                    'cks': int(error_line[9], 16),
+                                    'src': error_line[10],
+                                    'dst': error_line[11],
+                                }
+                            )
+                        except Exception:
+                            pass
+
+                        if response:
+                            ping_responses.append(response)
+
+                        ping_error = False
+                        continue
+
                 # normal response
-                else:
-                    line = line.replace(':', ' ').replace('=', ' ')
+                elif ' bytes from ' in line:
+                    try:
+                        line = line.replace(':', ' ').replace('=', ' ')
+
+                        response = {
+                            'type': 'reply',
+                            'bytes': line.split()[0],
+                            'response_ip': line.split()[3],
+                            'icmp_seq': line.split()[5],
+                            'ttl': line.split()[7],
+                            'time_ms': line.split()[9]
+                        }
+                    except Exception:
+                        response = {
+                            'type': 'unparsable_line',
+                            'unparsed_line': line
+                        }
+
+                    ping_responses.append(response)
+                    continue
+
+            # ipv6 lines
+            elif ' bytes from ' in line:
+                try:
+                    line = line.replace(',', ' ').replace('=', ' ')
                     response = {
                         'type': 'reply',
                         'bytes': line.split()[0],
@@ -442,20 +580,12 @@ def _bsd_parse(data):
                         'ttl': line.split()[7],
                         'time_ms': line.split()[9]
                     }
-                    ping_responses.append(response)
-                    continue
+                except Exception:
+                    response = {
+                        'type': 'unparsable_line',
+                        'unparsed_line': line
+                    }
 
-            # ipv6 lines
-            else:
-                line = line.replace(',', ' ').replace('=', ' ')
-                response = {
-                    'type': 'reply',
-                    'bytes': line.split()[0],
-                    'response_ip': line.split()[3],
-                    'icmp_seq': line.split()[5],
-                    'ttl': line.split()[7],
-                    'time_ms': line.split()[9]
-                }
                 ping_responses.append(response)
                 continue
 
@@ -463,8 +593,9 @@ def _bsd_parse(data):
     if ping_responses:
         seq_list = []
         for reply in ping_responses:
-            seq_list.append(reply['icmp_seq'])
-            reply['duplicate'] = True if seq_list.count(reply['icmp_seq']) > 1 else False
+            if 'icmp_seq' in reply:
+                seq_list.append(reply['icmp_seq'])
+                reply['duplicate'] = True if seq_list.count(reply['icmp_seq']) > 1 else False
 
     raw_output['responses'] = ping_responses
 
