@@ -13,9 +13,14 @@ Usage (module):
     import jc.parsers.systemctl_luf
     result = jc.parsers.systemctl_luf.parse(systemctl_luf_command_output)
 
-Compatibility:
+Schema:
 
-    'linux'
+    [
+      {
+        "unit_file":   string,
+        "state":       string
+      }
+    ]
 
 Examples:
 
@@ -40,7 +45,8 @@ import jc.utils
 
 
 class info():
-    version = '1.3'
+    """Provides parser metadata (version, author, etc.)"""
+    version = '1.4'
     description = '`systemctl list-unit-files` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -53,7 +59,7 @@ class info():
 __version__ = info.version
 
 
-def process(proc_data):
+def _process(proc_data):
     """
     Final processing to conform to the schema.
 
@@ -63,14 +69,7 @@ def process(proc_data):
 
     Returns:
 
-        List of Dictionaries. Structured data with the following schema:
-
-        [
-          {
-            "unit_file":   string,
-            "state":       string
-          }
-        ]
+        List of Dictionaries. Structured data to conform to the schema.
     """
     # nothing more to process
     return proc_data
@@ -122,4 +121,4 @@ def parse(data, raw=False, quiet=False):
     if raw:
         return raw_output
     else:
-        return process(raw_output)
+        return _process(raw_output)
